*** syntax dataset 2_2  marriages in Cumberland County, PA, in 1993.

GET
  FILE='C:\Documents and Settings\gvm\My Documents\onderwijs\spss\datasets\paired_2samples.SAV'.

COMPUTE agediff = husband-wife .
EXECUTE .
VAR LAB agediff 'age difference'.
FORMAT agediff (F5.0).

* listing of the data.
SUMMARIZE
  /TABLES=couple husband wife agediff
  /FORMAT=VALIDLIST NOCASENUM TOTAL
  /TITLE='Case Summaries'
  /MISSING=VARIABLE
  /CELLS=COUNT .

* frequency distribution (gives an idea on outliers, on ties also).
FREQUENCIES
  VARIABLES=couple husband wife agediff
  /ORDER=  ANALYSIS .
FREQUENCIES
  VARIABLES= husband wife agediff /FORMAT=NOTABLE
  /NTILES=  4
  /STATISTICS=STDDEV RANGE MINIMUM MAXIMUM MEAN MEDIAN SKEWNESS SESKEW KURTOSIS SEKURT
  /ORDER=  ANALYSIS .

* Basic Tables.
TABLES
  /FORMAT BLANK MISSING('.')
  /OBSERVATION husband wife agediff
  /TABLES (STATISTICS)
  BY (husband + wife + agediff)
  /STATISTICS
  validn(  'n')
  mean( ( COMMA8.1 ) 'mean')
  stddev( ( COMMA8.1 ) 'SD')
  median( ( COMMA8.1 ) 'median')
  ptile 25( ( COMMA8.1 ) 'Q1')
  ptile 75( ( COMMA8.1 ) 'Q3')
  minimum( ( COMMA8.1 ) 'range')
  maximum( ( COMMA8.1 ) '').

* exploratory data description: descriptive parameters and graphical representation.
EXAMINE
  VARIABLES=agediff
  /PLOT BOXPLOT STEMLEAF
  /COMPARE GROUP
  /STATISTICS NONE
  /CINTERVAL 95
  /MISSING LISTWISE
  /NOTOTAL.

* Q-Q plot - visual test of Gaussian distribution.
PPLOT
  /VARIABLES=agediff
  /NOLOG
  /NOSTANDARDIZE
  /TYPE=Q-Q
  /FRACTION=BLOM
  /TIES=MEAN
  /DIST=NORMAL.

* Kolmogorov-Smirnov test.
NPAR TESTS
  /K-S(NORMAL)= agediff
  /MISSING ANALYSIS.

* paired Student's t-test (parametric).
T-TEST
  PAIRS = husband  WITH wife (PAIRED)
  /CRITERIA = CI(.95)
  /MISSING = ANALYSIS.

* Wilcoxon matched-pairs signed-ranks test (nonparametric).
NPAR TEST
  /WILCOXON=husband  WITH wife (PAIRED)
  /MISSING ANALYSIS.
* Wilcoxon matched-pairs signed-ranks exact test.
NPAR TEST
  /WILCOXON=husband  WITH wife (PAIRED)
  /MISSING ANALYSIS
  /METHOD=EXACT TIMER(5).

* interactive graphs - scatterplot.
IGRAPH /VIEWNAME='Scatterplot' /X1 = VAR(wife) TYPE = SCALE /Y = VAR(husband) TYPE = SCALE /COORDINATE = VERTICAL  /FITLINE
  METHOD = LLR NORMAL BANDWIDTH = CONSTRAINED X1MULTIPLIER = 1.00  X2MULTIPLIER = 1.00 LINE = TOTAL SPIKE=OFF
 /TITLE="Husband's and wive's ages at marriage" /X1LENGTH=3.0 /YLENGTH=3.0 /X2LENGTH=3.0 /CHARTLOOK='NONE' /SCATTER COINCIDENT
  = NONE.
EXE.

* scatterplot.
GRAPH
  /SCATTERPLOT(BIVAR)=wife WITH husband
  /MISSING=LISTWISE
  /TITLE= "Husband's and wive's ages at marriage".

* Pearson correlation (parametric).
CORRELATIONS
  /VARIABLES=husband wife
  /PRINT=TWOTAIL NOSIG
  /MISSING=PAIRWISE .

* Spearman correlation (nonparametric).
NONPAR CORR
  /VARIABLES=husband wife
  /PRINT=BOTH TWOTAIL NOSIG
  /MISSING=PAIRWISE .

* linear regression.
REGRESSION
  /MISSING LISTWISE
  /STATISTICS COEFF OUTS CI R ANOVA
  /CRITERIA=PIN(.05) POUT(.10)
  /NOORIGIN
  /DEPENDENT husband
  /METHOD=ENTER wife
  /SCATTERPLOT=(husband ,*SRESID )
  /RESIDUALS HIST(ZRESID) NORM(ZRESID) .
