*** syntax dataset 2_1  Berger et al (1988).

GET
  FILE='C:\Documents and Settings\gvm\My Documents\onderwijs\spss\datasets\unpaired_2samples_cont.SAV'.

* listing of the data.
SUMMARIZE
  /TABLES=rat lifespan diet
  /FORMAT=VALIDLIST NOCASENUM TOTAL
  /TITLE='Case Summaries'
  /MISSING=VARIABLE
  /CELLS=COUNT .

* frequency distribution (gives an idea on outliers, on ties also).
FREQUENCIES
  VARIABLES=rat lifespan diet
  /ORDER=  ANALYSIS .

* exploratory data description: descriptive parameters and graphical representation.
EXAMINE
  VARIABLES=lifespan BY diet
  /PLOT BOXPLOT STEMLEAF HISTOGRAM NPPLOT
  /COMPARE GROUP
  /STATISTICS DESCRIPTIVES EXTREME
  /CINTERVAL 95
  /MISSING LISTWISE
  /NOTOTAL.

* interactive graphs - histogram.
IGRAPH /VIEWNAME='Histogram' /X1 = VAR(lifespan) TYPE = SCALE /Y = $count /COORDINATE = VERTICAL /PANEL VAR(diet)
 /X1LENGTH=3.0 /YLENGTH=3.0 /X2LENGTH=3.0 /CHARTLOOK='NONE' /CATORDER VAR(diet) (ASCENDING VALUES OMITEMPTY) /Histogram  SHAPE
  = HISTOGRAM CURVE = OFF X1INTERVAL AUTO X1START = 0.
EXE.

* interactive graphs - box-and-whisker plot.
IGRAPH /VIEWNAME='Boxplot' /X1 = VAR(diet) TYPE = CATEGORICAL /Y = VAR(lifespan) TYPE = SCALE  /COORDINATE = VERTICAL
 /X1LENGTH=3.0 /YLENGTH=3.0 /X2LENGTH=3.0 /CHARTLOOK='C:\Program Files\SPSS\Looks\Classic.clo' /CATORDER VAR(diet) (ASCENDING
  VALUES OMITEMPTY) /BOX OUTLIERS = ON EXTREME = ON MEDIAN = ON WHISKER = T.
EXE.

* tables with appropriate descriptives (down).
TABLES
  /FORMAT BLANK MISSING('.')
  /OBSERVATION lifespan 
  /TABLES diet > (STATISTICS)
  BY (lifespan)
  /STATISTICS
  validn(  'n')
  mean( ( COMMA8.1 ) 'mean')
  stddev( ( COMMA8.1 ) 'SD')
  median( ( COMMA8.1 ) 'median')
  ptile 25( ( COMMA8.1 ) 'Q1')
  ptile 75( ( COMMA8.1 ) 'Q3')
  minimum( ( COMMA8.1 ) 'range')
  maximum( ( COMMA8.1 ) '').

* tables with appropriate descriptives (across).
TABLES
  /FORMAT BLANK MISSING('.')
  /OBSERVATION lifespan
  /TABLES lifespan
  BY diet
  /STATISTICS
  validn(  'n')
  mean( ( COMMA8.1 ) 'gemiddelde')
  stddev( ( COMMA8.1 ) 'SD')
  median( ( COMMA8.1 ) 'mediaan')
  ptile 25( ( COMMA8.1 ) 'Q1')
  ptile 75( ( COMMA8.1 ) 'Q3')
  minimum( ( COMMA8.1 ) 'range')
  maximum( ( COMMA8.1 ) '').

* Q-Q plot for splitted datafile.
SORT CASES BY diet .
SPLIT FILE
  LAYERED BY diet .
PPLOT
  /VARIABLES=lifespan
  /NOLOG
  /NOSTANDARDIZE
  /TYPE=Q-Q
  /FRACTION=BLOM
  /TIES=MEAN
  /DIST=NORMAL.
SPLIT FILE
  OFF.

* box-and-whisker plot.
EXAMINE
  VARIABLES=lifespan BY diet /PLOT=BOXPLOT/STATISTICS=NONE/NOTOTAL.


* unpaired Student's t-test (parametric).
T-TEST
  GROUPS = diet(1 2)
  /MISSING = ANALYSIS
  /VARIABLES = lifespan
  /CRITERIA = CI(.95) .

* Mann-Whitney U-test (nonparametric).
NPAR TESTS
  /M-W= lifespan   BY diet(1 2)
  /MISSING ANALYSIS.

* Mann-Whitney U-test (nonparametric - exact test).
NPAR TESTS
  /M-W= lifespan   BY diet(1 2)
  /MISSING ANALYSIS
  /METHOD=EXACT TIMER(5).
